/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.artifact;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;


public class SOAPMessagePayloadKVP implements Payload {

    private Map mParameterMap;

    private String mPrefix = "";

    private String mSuffix = "";

    public SOAPMessagePayloadKVP() {
        mParameterMap = new LinkedHashMap();
    }

    public Iterator iterator() {
        return mParameterMap.entrySet().iterator();
    }

    public int size() {
        return mParameterMap.size();
    }

    public String getParameterValue(String pKey) {
        // Clarify: what is returned if param=value1,value2,value3? Just value1
        // or all values?
        Object lParamValue = mParameterMap.get(new Key(pKey));
        return (lParamValue == null) ? null : (String) lParamValue;
    }

    public String[] getParameterValues(String pKey) {
        String lValues = getParameterValue(pKey);

        if (lValues.equals(""))
            return new String[] {};

        String[] lSplittedValues = lValues.split(",", -1);
        return lSplittedValues;
    }

    public void replaceParameter(String pKey, String pValue) {
        mParameterMap.put(new Key(pKey), pValue);
    }

    public void addParameter(String pKey, String pValue) {
        Object lPrevKey = mParameterMap.put(new Key(pKey), pValue);
        /*
         * if (lPrevKey != null) throw new ServiceException("Query contains
         * duplicate parameter: " + pKey, ServiceException.SERVICE_ERROR);
         */// Ignore duplicates, could be a replacement
    }

    /**
     * Concatenates List elements separated by a certain String
     *
     * @param pList
     * @param pSeparator
     * @return
     */
    public static String listToString(List pList, String pSeparator) {

        if (pList.size() == 0)
            return "";

        StringBuffer lCSV = new StringBuffer();
        int i = 0;
        for (i = 0; i < pList.size() - 1; i++) {
            String tValue = (String) pList.get(i);
            lCSV.append(tValue + pSeparator);
        }

        String tValue = (String) pList.get(i);
        lCSV.append(tValue);

        return lCSV.toString();
    }

    public InputStream getAsStream() {
        return new ByteArrayInputStream(toString().getBytes());
    }

    public String toString() {
        List lKVPList = new ArrayList();
        Iterator itr = mParameterMap.entrySet().iterator();
        while (itr.hasNext()) {
            Map.Entry tEntry = (Map.Entry) itr.next();
            lKVPList.add(tEntry.getKey() + "=" + tEntry.getValue());
        }
        return mPrefix + listToString(lKVPList, "&") + mSuffix;
    }

    public void deleteParameter(String key) {
        mParameterMap.remove(new Key(key));

    }
}
