/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.artifact;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.io.StringWriter;

import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.TransformerFactoryConfigurationError;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.w3c.dom.Document;

public class SOAPMessagePayloadXML implements Payload {

    private Document m_Document;

    private org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(SOAPMessagePayloadXML.class);

    public SOAPMessagePayloadXML(Document soapBody) {
        m_Document = soapBody;
    }

    public InputStream getAsStream() {
        return new ByteArrayInputStream(toString().getBytes());
    }

    public Document getDocument() {
        return m_Document;
    }

    public String toString() {
        Transformer sTrans = null;
        StringWriter stringWriter = new StringWriter();
        try {
            sTrans = TransformerFactory.newInstance().newTransformer();
            sTrans.setOutputProperty(OutputKeys.INDENT, "yes");
            sTrans.transform(new DOMSource(m_Document), new StreamResult(stringWriter));
        } catch (TransformerException e) {
            LOG.error("Error transforming Document", e);
            throw new RuntimeException(e);
        } catch (TransformerFactoryConfigurationError e) {
            LOG.error("Error transforming Document", e);
            throw new RuntimeException(e);
        }
        return stringWriter.toString();
    }
}