/*
 * This source is a plain copy from bouncycastle software.
 * Thus:
 * Copyright (c) 2000 The Legion Of The Bouncy Castle (http://www.bouncycastle.org)
 */
package org.n52.security.common.crypto;

/**
 * Breaks up an X500 Name into its component tokens, ala
 * java.util.StringTokenizer. We need this class as some of the
 * lightweight Java environment don't support classes like
 * StringTokenizer.
 */
public class X509NameTokenizer {

    private String m_oid;
    private int m_index;
    private StringBuffer m_buf = new StringBuffer();

    public X509NameTokenizer(String oid) {
        this.m_oid = oid;
        this.m_index = -1;
    }

    public boolean hasMoreTokens() {
        return (m_index != m_oid.length());
    }

    public String nextToken() {
        if (m_index == m_oid.length()) {
            return null;
        }

        int end = m_index + 1;
        boolean quoted = false;
        boolean escaped = false;

        m_buf.setLength(0);

        while (end != m_oid.length()) {
            char c = m_oid.charAt(end);

            if (c == '"') {
                if (!escaped) {
                    quoted = !quoted;
                } else {
                    m_buf.append(c);
                }
                escaped = false;
            } else {
                if (escaped || quoted) {
                    m_buf.append(c);
                    escaped = false;
                } else if (c == '\\') {
                    escaped = true;
                } else if (c == ',') {
                    break;
                } else {
                    m_buf.append(c);
                }
            }
            end++;
        }

        m_index = end;
        return m_buf.toString().trim();
    }
}