/* Copyright (C) 2011 con terra GmbH (http://www.conterra.de)
 * All rights reserved
 */
package org.n52.security.common.uuid;

import java.text.FieldPosition;
import java.text.NumberFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

/**
 * Creates an ID based on the current time.
 */
public class TimeBasedIDGenerator implements IDGenerator {

    private SimpleDateFormat m_df;
    private NumberFormat m_nf;
    private Object m_lock = new Object();
    private int m_nanoCounter = 0;
    private long m_lastMillis = System.currentTimeMillis();

    public TimeBasedIDGenerator() {
        this("yyyyMMddHHmmssSSS");
    }

    public TimeBasedIDGenerator(String pattern) {
        m_nf = NumberFormat.getIntegerInstance(Locale.ENGLISH);
        m_nf.setGroupingUsed(false);
        m_nf.setMinimumIntegerDigits(3);
        setPattern(pattern);
    }

    public String getPattern() {
        return m_df.toPattern();
    }

    public void setPattern(final String pattern) {
        m_df = new SimpleDateFormat(pattern);
        m_df.setTimeZone(TimeZone.getTimeZone("UTC"));
    }

    @Override
    public String generateID() {
        long now = System.currentTimeMillis();
        int counter;
        synchronized (m_lock) {
            if (now == m_lastMillis) {
                counter = ++m_nanoCounter;
            } else {
                m_lastMillis = now;
                counter = m_nanoCounter = 0;
            }
        }
        StringBuffer uuid = m_df.format(new Date(now), new StringBuffer(), new FieldPosition(0));
        uuid.append(m_nf.format(counter));
        return uuid.toString();
    }
}
