/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 22.04.2008
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.xml;

import javax.xml.parsers.DocumentBuilder;

/**
 * Describes a pool for DocumentBuilders.
 * <p/>
 * Currently the usage of this class is encapsulated within the DOMParser class.
 *
 * @author Marko Reiprecht
 *         Created on 22.04.2008
 * @version $Revision: $
 */
public interface DocumentBuilderPool {

    /**
     * Acquires a DocumentBuilder with meets the requirements expressed by the options.
     *
     * @param options the options.
     * @return DocumentBuilder.
     * @throws DOMParserException if builder can not acquired.
     */
    DocumentBuilder acquire(DOMParserOptions options) throws DOMParserException;

    /**
     * Releases a DocumentBuilder, wich was acquired using the parser options.
     *
     * @param builder the builder.
     * @param options the options.
     */
    void release(DocumentBuilder builder, DOMParserOptions options);
}
